Improved Octave Interface for Sage
==================================

This project provides an improved version of the `SageMath` Octave interface.
It is based on: `sage/interfaces/octave.py <http://git.sagemath.org/sage.git/tree/src/sage/interfaces/octave.py>`_.
